@@ -1,4 +1,4 @@
-# Copyrights 2001-2023 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.03.
@@ -6,9 +6,9 @@
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package Mail::Box::POP3;
-use vars '$VERSION';
-$VERSION = '3.006';
+package Mail::Box::POP3;{
+our $VERSION = '3.007';
+}
 
 use base 'Mail::Box::Net';
 
